"""Auto-generated file, do not edit by hand. 675 metadata"""
from ..phonemetadata import NumberFormat

PHONE_ALT_FORMAT_675 = [NumberFormat(pattern='(7\\d{2})(\\d{2})(\\d{3})', format='\\1 \\2 \\3', leading_digits_pattern=['7'])]
